package graphicalUserInterface.createNewPlayer;

import database.DBConnection;
import database.utility.DominantHand;
import javafx.collections.FXCollections;
import javafx.collections.ObservableList;
import javafx.fxml.FXML;
import javafx.scene.control.ChoiceBox;
import javafx.scene.control.TextField;

import java.io.IOException;
import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.PreparedStatement;
import java.sql.SQLException;
import java.sql.Statement;
import java.util.logging.Level;
import java.util.logging.Logger;

import static graphicalUserInterface.Main.showCreateNewPlayerVerificationScene;
import static graphicalUserInterface.Main.showMainItems;

public class CreatePlayerController {
	public static final Logger logger = Logger.getLogger(CreatePlayerController.class.getName());

	private ObservableList<Integer> ageBoxList = FXCollections.observableArrayList(16, 17, 18, 19, 20, 21, 22, 23);
	private ObservableList<DominantHand> dominantHandBoxList = FXCollections.observableArrayList(DominantHand.Right,
			DominantHand.Left, DominantHand.Ambidextrous);

	@FXML
	private TextField nameField;
	@FXML
	private TextField weightField;
	@FXML
	private TextField heightField;
	@FXML
	private ChoiceBox<Integer> ageBox;
	@FXML
	private ChoiceBox<DominantHand> dominantHandBox;

	@FXML
	private void initialize() {
		ageBox.setValue(18);
		ageBox.setItems(ageBoxList);
		dominantHandBox.setValue(DominantHand.Right);
		dominantHandBox.setItems(dominantHandBoxList);
	}

	@FXML
	private void goCancel() throws IOException {
		showMainItems();
	}

	@FXML
	private void goConfirm() throws IOException, SQLException {
		Connection dbConnection = DBConnection.getInstance().getConnection();
		PreparedStatement stmt = null;
		try {
			stmt = dbConnection.prepareStatement(
					"INSERT INTO TheProjectData.Player (Height, Weight, Age, Name, Hand, Passes, Completions, Catches, Scores, Injured, GamesPlayed) Values (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)");
			stmt.setString(1, heightField.getText());
			stmt.setString(2, weightField.getText());
			stmt.setInt(3, ageBox.getValue());
			stmt.setString(4, nameField.getText());
			stmt.setString(5, dominantHandBox.getValue().toString());
			stmt.setInt(6, 0);
			stmt.setInt(7, 0);
			stmt.setInt(8, 0);
			stmt.setInt(9, 0);
			stmt.setInt(10, 0);
			stmt.setInt(11, 0);
			stmt.executeUpdate();
			showCreateNewPlayerVerificationScene();
		} finally {
			try {
				if (stmt != null) {
					stmt.close();
				}
			} catch (Exception e) {
				logger.log(Level.SEVERE, e.getMessage());
			}
			try {
				if (dbConnection != null) {
					dbConnection.close();
				}
			} catch (Exception e) {
				logger.log(Level.SEVERE, e.getMessage());
			}
		}

		dbConnection = null;
	}
}
